@@ -532,6 +532,7 @@ func (LinterBuilder) Build(cfg *config.Config) ([]*linter.Config, error) {
 		linter.NewConfig(noinlineerr.New()).
 			WithSince("v2.2.0").
 			WithLoadForGoAnalysis().
+			WithAutoFix().
 			WithURL("https://github.com/AlwxSin/noinlineerr"),
 
 		linter.NewConfig(nonamedreturns.New(&cfg.Linters.Settings.NoNamedReturns)).
@@ -619,7 +620,7 @@ func (LinterBuilder) Build(cfg *config.Config) ([]*linter.Config, error) {
 		linter.NewConfig(swaggo.New()).
 			WithSince("v2.2.0").
 			WithAutoFix().
-			WithURL("https://github.com/swaggo/swaggo"),
+			WithURL("https://github.com/swaggo/swag"),
 
 		linter.NewConfig(tagalign.New(&cfg.Linters.Settings.TagAlign)).
 			WithSince("v1.53.0").
